@@ -1,19 +1,12 @@
-/*************************************************************************
- *  Copyright (C) 2010 by Volker Lanz <vl@fidra.de>                      *
- *                                                                       *
- *  This program is free software; you can redistribute it and/or        *
- *  modify it under the terms of the GNU General Public License as       *
- *  published by the Free Software Foundation; either version 3 of       *
- *  the License, or (at your option) any later version.                  *
- *                                                                       *
- *  This program is distributed in the hope that it will be useful,      *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
- *  GNU General Public License for more details.                         *
- *                                                                       *
- *  You should have received a copy of the GNU General Public License    *
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
- *************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2010 Volker Lanz <vl@fidra.de>
+    SPDX-FileCopyrightText: 2015 Chris Campbell <c.j.campbell@ed.ac.uk>
+    SPDX-FileCopyrightText: 2016-2018 Andrius Štikonas <andrius@stikonas.eu>
+    SPDX-FileCopyrightText: 2018 Caio Jordão Carvalho <caiojcarvalho@gmail.com>
+    SPDX-FileCopyrightText: 2019 Yuri Chornoivan <yurchor@ukr.net>
+
+    SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #ifndef KPMCORE_SMARTATTRIBUTE_H
 #define KPMCORE_SMARTATTRIBUTE_H
@@ -46,7 +39,7 @@ public:
     };
 
 public:
-    SmartAttribute(const SmartAttributeParsedData& a);
+    explicit SmartAttribute(const SmartAttributeParsedData& a);
 
 public:
     qint32 id() const {
