@@ -1,22 +1,14 @@
-/*************************************************************************
- *  Copyright (C) 2008,2009 by Volker Lanz <vl@fidra.de>                 *
- *                                                                       *
- *  This program is free software; you can redistribute it and/or        *
- *  modify it under the terms of the GNU General Public License as       *
- *  published by the Free Software Foundation; either version 3 of       *
- *  the License, or (at your option) any later version.                  *
- *                                                                       *
- *  This program is distributed in the hope that it will be useful,      *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
- *  GNU General Public License for more details.                         *
- *                                                                       *
- *  You should have received a copy of the GNU General Public License    *
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
- *************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008-2010 Volker Lanz <vl@fidra.de>
+    SPDX-FileCopyrightText: 2013-2017 Andrius Štikonas <andrius@stikonas.eu>
+    SPDX-FileCopyrightText: 2015 Chris Campbell <c.j.campbell@ed.ac.uk>
+    SPDX-FileCopyrightText: 2020 Arnaud Ferraris <arnaud.ferraris@collabora.com>
+    SPDX-FileCopyrightText: 2020 Gaël PORTAY <gael.portay@collabora.com>
 
-#if !defined(KPMCORE_NTFS_H)
+    SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
+#ifndef KPMCORE_NTFS_H
 #define KPMCORE_NTFS_H
 
 #include "util/libpartitionmanagerexport.h"
@@ -37,7 +29,7 @@ namespace FS
 class LIBKPMCORE_EXPORT ntfs : public FileSystem
 {
 public:
-    ntfs(qint64 firstsector, qint64 lastsector, qint64 sectorsused, const QString& label, const QList<FSFeature>& features = {});
+    ntfs(qint64 firstsector, qint64 lastsector, qint64 sectorsused, const QString& label, const QVariantMap& features = {});
 
 public:
     void init() override;
